@@ -1,5 +1,3 @@
-context("sort")
-
 test_that("digits can be sorted/ordered as strings or numbers", {
   x <- c("2", "1", "10")
 
@@ -8,6 +6,9 @@ test_that("digits can be sorted/ordered as strings or numbers", {
 
   expect_equal(str_order(x, numeric = FALSE), c(2, 3, 1))
   expect_equal(str_order(x, numeric = TRUE), c(2, 1, 3))
+
+  expect_equal(str_rank(x, numeric = FALSE), c(3, 1, 2))
+  expect_equal(str_rank(x, numeric = TRUE), c(2, 1, 3))
 })
 
 test_that("NA can be at beginning or end", {
@@ -19,3 +20,9 @@ test_that("NA can be at beginning or end", {
   na_start <- str_sort(x, numeric = TRUE, na_last = FALSE)
   expect_equal(head(na_start, 1), NA_character_)
 })
+
+test_that("str_sort() preserves names", {
+  x <- c(C = "3", B = "2", A = "1")
+  out <- str_sort(x)
+  expect_equal(names(out), c("A", "B", "C"))
+})
